#!/usr/bin/env python3
import common

import argparse
import sys
from gitlab import Gitlab, GitlabJobRetryError

from get_merge_requests import get_merge_requests
from retrigger_mr_pipeline_job import retrigger_mr_pipeline_job


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--gitlab-url",
        help="""URL to the GitLab instance""",
        dest="gitlab_url",
        required=True,
    )
    parser.add_argument(
        "--token",
        help="""GitLab REST API private access token""",
        dest="token",
        required=True,
    )
    parser.add_argument(
        "--project",
        help="""name of the GitLab project""",
        dest="project",
        required=True,
    )
    parser.add_argument(
        "--state",
        help="""state of the merge request (opened, closed, locked, or merged)""",
        dest="state",
        required=True,
    )
    parser.add_argument(
        "--source-branch",
        help="""source branch of the merge request""",
        dest="source_branch",
        required=False,
    )
    parser.add_argument(
        "--target-branch",
        help="""target branch of the merge request""",
        dest="target_branch",
        required=False,
    )
    parser.add_argument(
        "--commit",
        help="""commit sha of the merge request""",
        dest="commit",
        required=False,
    )
    parser.add_argument(
        "--job",
        help="""job to retrigger""",
        dest="job",
        required=True,
    )

    args, _ = parser.parse_known_args()

    gitlab = Gitlab(args.gitlab_url, private_token=args.token)
    project = common.get_project(gitlab, args.project)

    mrs = get_merge_requests(
        project,
        state=args.state,
        source_branch=args.source_branch,
        target_branch=args.target_branch,
        commit=args.commit,
    )

    failed = 0
    for mr in mrs:
        try:
            retrigger_mr_pipeline_job(project, mr, args.job, ["success", "running"])
        except GitlabJobRetryError as e:
            print(
                "ERROR: Could not retrigger job '%s' of %s!%s: %s"
                % (args.job, args.project, mr.iid, e)
            )
            failed = failed + 1
            continue

    if failed > 0:
        sys.exit(1)


if __name__ == "__main__":
    main()
